#ifndef NT2_INCLUDE_CONSTANTS_MAXLEFTSHIFT_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_MAXLEFTSHIFT_HPP_INCLUDED

#include <nt2/constant/include/constants/maxleftshift.hpp>

#endif
